# Installation

It's recommended to install this package in a virtual environment:

```bash
python3 -m venv venv
source venv/bin/activate
```

Then, install the package:

```bash
pip install headwai
```
OR
```bash
pip install git+https://github.com/richard-headwai/headwai.git
```
